@@ -6,6 +6,7 @@ import tokenize as tk
 from collections import namedtuple
 from itertools import chain, takewhile
 from re import compile as re
+from textwrap import dedent
 
 from . import violations
 from .config import IllegalConfiguration
@@ -122,6 +123,8 @@ class ConventionChecker:
         r"\s*"
         # Followed by a colon
         r":"
+        # Might have a new line and leading whitespace
+        r"\n?\s*"
         # Followed by 1 or more characters - which is the docstring for the parameter
         ".+"
     )
@@ -131,8 +134,12 @@ class ConventionChecker:
         source,
         filename,
         ignore_decorators=None,
+        property_decorators=None,
         ignore_inline_noqa=False,
     ):
+        self.property_decorators = (
+            {} if property_decorators is None else property_decorators
+        )
         module = parse(StringIO(source), filename)
         for definition in module:
             for this_check in self.checks:
@@ -192,12 +199,7 @@ class ConventionChecker:
               with a single underscore.
 
         """
-        if (
-            not docstring
-            and definition.is_public
-            or docstring
-            and is_blank(ast.literal_eval(docstring))
-        ):
+        if not docstring and definition.is_public:
             codes = {
                 Module: violations.D100,
                 Class: violations.D101,
@@ -223,6 +225,18 @@ class ConventionChecker:
             }
             return codes[type(definition)]()
 
+    @check_for(Definition, terminal=True)
+    def check_docstring_empty(self, definition, docstring):
+        """D419: Docstring is empty.
+
+        If the user provided a docstring but it was empty, it is like they never provided one.
+
+        NOTE: This used to report as D10X errors.
+
+        """
+        if docstring and is_blank(ast.literal_eval(docstring)):
+            return violations.D419()
+
     @check_for(Definition)
     def check_one_liners(self, definition, docstring):
         """D200: One-liner docstrings should fit on one line with quotes.
@@ -500,7 +514,11 @@ class ConventionChecker:
         "Returns the pathname ...".
 
         """
-        if docstring and not function.is_test:
+        if (
+            docstring
+            and not function.is_test
+            and not function.is_property(self.property_decorators)
+        ):
             stripped = ast.literal_eval(docstring).strip()
             if stripped:
                 first_word = strip_non_alphanumeric(stripped.split()[0])
@@ -828,10 +846,38 @@ class ConventionChecker:
             * The section documents all function arguments (D417)
                 except `self` or `cls` if it is a method.
 
+        Documentation for each arg should start at the same indentation
+        level. For example, in this case x and y are distinguishable::
+
+            Args:
+                x: Lorem ipsum dolor sit amet
+                y: Ut enim ad minim veniam
+
+        In the case below, we only recognize x as a documented parameter
+        because the rest of the content is indented as if it belongs
+        to the description for x::
+
+            Args:
+                x: Lorem ipsum dolor sit amet
+                    y: Ut enim ad minim veniam
         """
         docstring_args = set()
-        for line in context.following_lines:
-            match = ConventionChecker.GOOGLE_ARGS_REGEX.match(line)
+        # normalize leading whitespace
+        args_content = dedent("\n".join(context.following_lines)).strip()
+
+        args_sections = []
+        for line in args_content.splitlines(keepends=True):
+            if not line[:1].isspace():
+                # This line is the start of documentation for the next
+                # parameter because it doesn't start with any whitespace.
+                args_sections.append(line)
+            else:
+                # This is a continuation of documentation for the last
+                # parameter because it does start with whitespace.
+                args_sections[-1] += line
+
+        for section in args_sections:
+            match = ConventionChecker.GOOGLE_ARGS_REGEX.match(section)
             if match:
                 docstring_args.add(match.group(1))
         yield from ConventionChecker._check_missing_args(
@@ -1040,6 +1086,7 @@ def check(
     select=None,
     ignore=None,
     ignore_decorators=None,
+    property_decorators=None,
     ignore_inline_noqa=False,
 ):
     """Generate docstring errors that exist in `filenames` iterable.
@@ -1092,7 +1139,11 @@ def check(
             with tk.open(filename) as file:
                 source = file.read()
             for error in ConventionChecker().check_source(
-                source, filename, ignore_decorators, ignore_inline_noqa
+                source,
+                filename,
+                ignore_decorators,
+                property_decorators,
+                ignore_inline_noqa,
             ):
                 code = getattr(error, 'code', None)
                 if code in checked_codes:
